.. include:: ../README.rst


.. toctree::
   :maxdepth: 1
   :caption: User Guide

   API Documentation <api/pykoopman>
   Examples <examples/index>

.. toctree::
   :maxdepth: 1
   :caption: Useful links


   PyKoopman @ PyPI <https://pypi.org/project/pykoopman/>
   Issue Tracker <https://github.com/dynamicslab/pykoopman/issues>